"use client";
import { AiOutlineClose } from "react-icons/ai";
import Link from "next/link";
import prodImg from "/public/product/prod-1.jpg";
import { Swiper, SwiperSlide } from "swiper/react";
import "swiper/swiper.min.css";
import Product from "../shared/product/Product";
import Image from "next/image";
import Enquiry from "./Enquiry";
import { useDispatch, useSelector } from "react-redux";
import { IMAGEURL } from "@/Api/apiConfig";
import { deleteProduct } from "@/Redux/cartSlice";

const Cart = () => {
  const cartItems = useSelector((state) => state?.userCart?.products);
  const dispatch = useDispatch();
  const getImg = (row) => {
    if (row?.image) {
      return `${IMAGEURL}${row?.image}`;
    } else if (row?.images?.length > 0) {
      const filter = row?.images?.filter((ele) => ele?.url);
      if (filter?.length > 0) {
        return `${IMAGEURL}${filter[0].url}`;
      }
    }
  };
  const handleRemoveItem = (row) => {
    dispatch(deleteProduct(row));
  };

  const getTotal = () => {
    const sum = cartItems?.reduce((a, c) => {
      return c.qty * c.model.price + a;
    }, 0);

    return sum;
  };
  return (
    <>
      <section className="py-5">
        <div className="side-space">
          <div className="view-cart">
            <div className="grid  grid-cols-12">
              <div className="col-span-12">
                <div className="common-heading text-left mb-3">
                  <h3 className="font-Butler-Normal">SHOPPING CART</h3>
                </div>
                <hr />
                <div className="table-responsive">
                  {cartItems?.length > 0 && (
                    <table className="table border w-100 mb-0">
                      <thead>
                        <tr className="bg-gray-100">
                          <th>Products</th>
                          <th>Price</th>
                          <th>Item Code</th>
                          <th>Qty</th>
                          <th>Sub Total</th>
                          <th></th>
                        </tr>
                      </thead>
                      <tbody>
                        {cartItems?.map((row, index) => (
                          <tr key={index}>
                            <td>
                              <div className="flex w-[100%]">
                                <div>
                                  <Image
                                    src={getImg(row)}
                                    width={80}
                                    height={120}
                                    className="w-[80px] h-[80px] mr-5"
                                    alt="product"
                                    // className="w-[100px]  h-[60px] md:h-[80px] mr-5"
                                  />
                                </div>
                                <div>
                                  <p className="mb-0 text-sm text-[#333] font-normal">
                                    {row?.product_name ?? "not given"}
                                  </p>
                                  <p className="mb-0 flex text-sm text-[#333] font-normal">
                                    <span className="me-2">
                                      <b>Category:</b>{" "}
                                      {row?.category ?? "not given"}
                                    </span>{" "}
                                    |{" "}
                                    <span className="ms-2">
                                      <b>Sub Category:</b>{" "}
                                      {row?.sub_category ?? "not given"}
                                    </span>
                                  </p>
                                </div>
                              </div>
                            </td>
                            <td>₹ {row?.model?.price ?? "not given"}</td>
                            <td>{row?.model?.product_modal ?? "not given"}</td>
                            <td>
                              {row?.qty}
                              {/* <ProductQty /> */}
                            </td>
                            <td>₹{+row?.qty * +row?.model?.price}</td>
                            <td>
                              <button onClick={() => handleRemoveItem(row)}>
                                <AiOutlineClose className="text-lg font-semibold" />
                              </button>
                            </td>
                          </tr>
                        ))}
                        <tr>
                          <td></td>
                          <td></td>
                          <td></td>
                          <td>
                            <b>Total</b>
                          </td>
                          <td>₹{getTotal()} </td>
                        </tr>
                      </tbody>
                    </table>
                  )}
                  {cartItems?.length == 0 && (
                    <div className="text-center">
                      <h4>Cart is Empty!</h4>
                    </div>
                  )}
                </div>
              </div>
            </div>
          </div>

          <div className="enquiry_form mt-3 mt-md-5">
              <div className="common-heading text-center mb-3">
                <h3 className="text-left">Customers Also Brought </h3>
                <div className="line"></div>
              </div>
              <div className="mt-5">
                <div className="category-list col-span-12">
                      <Swiper
                        slidesPerView={5.3}
                        spaceBetween={25}
                        loop={true}
                        autoplay={{ delay: 2500 }}
                        navigation={false}
                        pagination={{ clickable: true }}
                        breakpoints={{
                          320: { slidesPerView: 1.1 },
                          480: { slidesPerView: 2.2 },
                          770: { slidesPerView: 3 },
                          1030: { slidesPerView: 4 },
                          1340: { slidesPerView: 5.3 },
                        }}
                      >
                    
                        {[1, 2, 3, 4, 5, 6, 7].map((index) => (
                          <SwiperSlide key={index}>
                            <Product />
                          </SwiperSlide>
                        ))}
                      </Swiper>
                  </div>
              </div>
          </div>

        </div>
      </section>
    </>
  );
};

export default Cart;
