"use client";

import authApi from "@/Api/authApi";
import { useState } from "react";
import { toast } from "react-toastify";

const initialState = {
  name: "",
  email: "",
  message: "",
  phone: "",
};
const ContactForm = () => {
  const [state, setState] = useState(initialState);
  const [saving, setSaving] = useState(false);

  const handleSubmit = async (e) => {
    e.preventDefault();
    setSaving(true);
    try {
      await authApi.post("save-contact", state);
      setState(initialState);
      setSaving(false);
      toast.success("Form submitted successfully.");
    } catch (error) {
      setSaving(false);
      toast.error(error?.response?.data?.message);
    }
  };

  return (
    <>
      <div className="">
        <form onSubmit={(e) => handleSubmit(e)}>
          <div className="block sm:flex  gap-5">
            <div className="mb-3 flex-1">
              <label className="text-[#666] text-sm">
                {" "}
                Name <span className=" text-red-500 ">*</span>
              </label>
              <input
                type="text"
                className="p-[14px] !border w-100 rounded bg-gray-100  focus:outline-none"
                placeholder="Name"
                required
                value={state?.name}
                onChange={(e) => setState({ ...state, name: e.target.value })}
              />
            </div>

            <div className="mb-3 flex-1">
              <label className="text-[#666] text-sm">
                {" "}
                Phone <span className=" text-red-500 ">*</span>
              </label>
              <input
                type="tel"
                className="p-[14px] !border w-100 rounded bg-gray-100  focus:outline-none"
                placeholder="phone"
                required
                value={state?.phone}
                onChange={(e) => setState({ ...state, phone: e.target.value })}
              />
            </div>
          </div>

          <div className="block sm:flex gap-5">
            <div className="mb-3 flex-1">
              <label className="text-[#666] text-sm">
                {" "}
                Email<span className=" text-red-500 ">*</span>
              </label>
              <input
                required
                type="email"
                className="p-[14px] !border w-100 rounded bg-gray-100  focus:outline-none"
                placeholder="Email"
                value={state?.email}
                onChange={(e) => setState({ ...state, email: e.target.value })}
              />
            </div>
          </div>

          <div className="block sm:flex gap-5">
            <div className="mb-3 flex-1">
              <label className="text-[#666] text-sm">
                {" "}
                Message <span className=" text-red-500 "></span>
              </label>
              <textarea
                className="!border w-100 bg-gray-100 rounded p-[14px] focus:outline-none"
                rows="8"
                required
                placeholder="Write Your Query.."
                value={state?.message}
                onChange={(e) =>
                  setState({ ...state, message: e.target.value })
                }
              ></textarea>
            </div>
          </div>

          <div className="block sm:flex justify-center">
            <button
              disabled={saving}
              className="rounded-full w-fit transition-all text-[14px] flex items-center gap-2 bg-[#000] border-1 border-[#000] hover:border-[#3333]  py-2 px-5  lg:px-10 md:py-3  text-md text-[#fff] font-normal  leading-[24px] no-underline hover:text-[#fff] hover:bg-[#333] hover:border-[#6f6f6f]"
            >
              {saving ? "SUBMITTING" : "SUBMIT"}
            </button>
          </div>
        </form>
      </div>
    </>
  );
};

export default ContactForm;
