import authApi from "@/Api/authApi";
import { useState } from "react";
import { toast } from "react-toastify";

const initialState = {
  profession: "",
  name: "",
  email: "",
  phone: "",
  address: "",
  city: "",
  state: "",
  zipcode: "",
  country: "",
  message: "",
};
const Form = () => {
  const [state, setState] = useState(initialState);
  const [saving, setSaving] = useState(false);
  const handleSubmit = async (e) => {
    e.preventDefault();
    setSaving(true);
    try {
      await authApi.post("create-dealer", state);
      setState(initialState)
      setSaving(false);
      toast.success('Form submitted successfully.')
    } catch (error) {
      toast?.error(error?.response?.data?.message);
      setSaving(false);
    }
  };

  return (
    <>
      <div className="w-[100%]  lg:w-[75%] m-auto !border-[10px] rounded p-4 bg-[#7b7b7b17]">
        <form onSubmit={(e) => handleSubmit(e)}>
          <div className="block sm:flex gap-5">
            <div className="mb-3 flex-1"> 
              <label className="text-[#666] text-sm">
                Profession<span className=" text-red-500 ">*</span>
              </label>
              <select
                required
                className="p-[12px] !border w-100 bg-[#fff] rounded  focus:outline-none border-[#3333335e] hover:border-[#29abe2]"
                value={state?.profession}
                onChange={(e) =>
                  setState({ ...state, profession: e.target.value })
                }
              >
                <option value="">Select</option>
                <option value="Architect">Architect</option>
                <option value="Interior Designer">Interior Designer</option>
                <option value="Engineer">Engineer</option>
                <option value="Developer">Developer</option>
                <option value="Dealer">Dealer</option>
                <option value="Contractor">Contractor</option>
              </select>
            </div>

            <div className="mb-3 flex-1">
              <label className="text-[#666] text-sm">
                {" "}
                Name <span className=" text-red-500 ">*</span>
              </label>
              <input
                type="text"
                className="p-[14px] !border w-100 rounded bg-[#fff]  focus:outline-none border-[#3333335e] hover:border-[#29abe2]"
                placeholder="Name"
                required
                value={state?.name}
                onChange={(e) => setState({ ...state, name: e.target.value })}
              />
            </div>
          </div>

          <div className="block sm:flex gap-5">
            <div className="mb-3 flex-1">
              <label className="text-[#666] text-sm">
                {" "}
                Phone <span className=" text-red-500 ">*</span>
              </label>
              <input
                type="tel"
                className="p-[14px] !border w-100 rounded bg-[#fff]  focus:outline-none border-[#3333335e] hover:border-[#29abe2]"
                placeholder="phone"
                required
                value={state?.phone}
                onChange={(e) => setState({ ...state, phone: e.target.value })}
              />
            </div>

            <div className="mb-3 flex-1">
              <label className="text-[#666] text-sm">
                {" "}
                Email<span className=" text-red-500 ">*</span>
              </label>
              <input
                type="email"
                required
                className="p-[14px] !border w-100 rounded bg-[#fff]  focus:outline-none border-[#3333335e] hover:border-[#29abe2]"
                placeholder="Email"
                value={state?.email}
                onChange={(e) => setState({ ...state, email: e.target.value })}
              />
            </div>
          </div>

          <div className="block sm:flex gap-5">
            <div className="mb-3 flex-1">
              <label className="text-[#666] text-sm">
                {" "}
                City<span className=" text-red-500 ">*</span>
              </label>
              <input
                type="text"
                className="p-[14px] !border w-100 rounded bg-[#fff]  focus:outline-none border-[#3333335e] hover:border-[#29abe2]"
                placeholder="City"
                required
                value={state?.city}
                onChange={(e) => setState({ ...state, city: e.target.value })}
              />
            </div>

            <div className="mb-3 flex-1">
              <label className="text-[#666] text-sm">
                {" "}
                State<span className=" text-red-500 ">*</span>
              </label>
              <input
                type="text"
                className="p-[14px] !border w-100 rounded bg-[#fff]  focus:outline-none border-[#3333335e] hover:border-[#29abe2]"
                placeholder="State"
                required
                value={state?.state}
                onChange={(e) => setState({ ...state, state: e.target.value })}
              />
            </div>
          </div>

          <div className="block sm:flex gap-5">
            <div className="mb-3 flex-1">
              <label className="text-[#666] text-sm">
                {" "}
                Postal Code <span className=" text-red-500 ">*</span>
              </label>
              <input
                type="text"
                className="p-[14px] !border w-100 rounded bg-[#fff]  focus:outline-none border-[#3333335e] hover:border-[#29abe2]"
                placeholder="Postal Code"
                value={state?.zipcode}
                required
                onChange={(e) =>
                  setState({ ...state, zipcode: e.target.value })
                }
              />
            </div>

            <div className="mb-3 flex-1">
              <label className="text-[#666] text-sm">
                {" "}
                Country <span className=" text-red-500 ">*</span>
              </label>
              <input
                type="text"
                className="p-[14px] !border w-100 rounded bg-[#fff]  focus:outline-none border-[#3333335e] hover:border-[#29abe2]"
                placeholder="Country"
                required
                value={state?.country}
                onChange={(e) =>
                  setState({ ...state, country: e.target.value })
                }
              />
            </div>
          </div>

          <div className="block sm:flex gap-5">
            <div className="mb-3 flex-1">
              <label className="text-[#666] text-sm">
                {" "}
                Address <span className=" text-red-500 ">*</span>
              </label>
              <textarea
                className="!border w-100 bg-[#fff] rounded p-[14px] focus:outline-none border-[#3333335e] hover:border-[#29abe2]"
                rows="3"
                placeholder="Address..."
                required
                value={state?.address}
                onChange={(e) =>
                  setState({ ...state, address: e.target.value })
                }
              ></textarea>
            </div>
          </div>

          <div className="block sm:flex gap-5">
            <div className="mb-3 flex-1">
              <label className="text-[#666] text-sm">
                {" "}
                Message <span className=" text-red-500 "></span>
              </label>
              <textarea
                className="!border w-100 bg-[#fff] rounded p-[14px] focus:outline-none border-[#3333335e] hover:border-[#29abe2]"
                rows="8"
                placeholder="Write Your Query.."
                value={state?.message}
                onChange={(e) =>
                  setState({ ...state, message: e.target.value })
                }
              ></textarea>
            </div>
          </div>

          <div className="flex justify-center">
            <button
              type="submit"
              className="rounded-full flex w-fit transition-all text-[14px]  items-center gap-2 bg-[#000] border-1 border-[#000] hover:border-[#3333]  py-2 px-4  lg:px-8 md:py-3  text-md text-[#fff] font-normal  leading-[24px] no-underline hover:text-[#fff] hover:bg-[#333] hover:border-[#6f6f6f]"
              disabled={saving}
            >
              {saving ? "Submitting" : "Submit"}
            </button>
          </div>
        </form>
      </div>
    </>
  );
};

export default Form;
