"use client";
import { Swiper, SwiperSlide } from "swiper/react";
import "swiper/swiper.min.css";
import Product from "../../shared/product/Product";
import { useEffect, useState } from "react";
import authApi from "@/Api/authApi";
import CustomLink from "@/app/shared/CustomLink";

const SellingProducts = () => {
  const [allProducts, setAllProducts] = useState([]);
  const [isLoading, setIsLoading] = useState(true);

  const getAllTrendingProducts = async () => {
    setIsLoading(true);
    try {
      const res = await authApi.get(`get-trending-product`);
      console.log("response", res);
      setAllProducts(res?.data?.products);
      setIsLoading(false);
    } catch (error) {
      setIsLoading(false);
    }
  };

  useEffect(() => {
    getAllTrendingProducts();
  }, []);

  return (
    <>
      <section className="py-[40px] md:py-[60px] lg:py-[80px]">
        <div className="side-space">
            <div className="">
              <div className="flex justify-between items-start">
                <div className="common-heading mb-3 mb-sm-4">
                  <h3>Best seller products </h3>
                </div>

                <div className="mb-3 mb-sm-3 c-width"> 
                  <CustomLink
                    href="/shop"
                    title="View All"
                    bgColor="#000"
                    hoverBgColor="#2eb7f1"
                    textColor="#ffffff"
                    hoverTextColor="#fff"
                    borderColor="#333"
                    showArrow={true}
                  />
                </div>
              </div>

              <div className="grid gap-[0.75rem] grid-cols-12 w-full">
                <div className="category-list col-span-12">
                  <Swiper
                    slidesPerView={5.3}
                    spaceBetween={25}
                    loop={true}
                    autoplay={{ delay: 2500 }}
                    navigation={false}
                    pagination={{ clickable: true }}
                    breakpoints={{
                      320: { slidesPerView: 1.1 },
                      480: { slidesPerView: 2.2 },
                      770: { slidesPerView: 3 },
                      1030: { slidesPerView: 4 },
                      1340: { slidesPerView: 5 },
                    }}
                  >
                    {/* {allProducts?.map((row,index)=>
         <SwiperSlide key={index}>
            <Product row={row}  />
          </SwiperSlide>)} */}
                    {[1, 2, 3, 4, 5, 6, 7].map((index) => (
                      <SwiperSlide key={index}>
                        <Product />
                      </SwiperSlide>
                    ))}
                  </Swiper>
                </div>
              </div>
            </div>
          </div>
      </section>
    </>
  );
};

export default SellingProducts;
