"use client";
import { Swiper, SwiperSlide } from "swiper/react";
import "swiper/swiper.min.css";
import Product from "../../shared/product/Product";
import { useEffect, useState } from "react";
import authApi from "@/Api/authApi";
import CustomLink from "@/app/shared/CustomLink";
import "./deal_of_day.css";
import ProductImg from "/public/product/prod-1.jpg"
import Image from "next/image";

const TrendingProduct = () => {
  const [allProducts, setAllProducts] = useState([]);
  const [isLoading, setIsLoading] = useState(true);

  const getAllTrendingProducts = async () => {
    setIsLoading(true);
    try {
      const res = await authApi.get(`get-trending-product`);
      console.log("response", res);
      setAllProducts(res?.data?.products);
      setIsLoading(false);
    } catch (error) {
      setIsLoading(false);
    }
  };

  useEffect(() => {
    getAllTrendingProducts();
  }, []);

  return (
    <>
      <section className="py-[40px] md:py-[60px] lg:py-[80px]">
        <div className="side-space">
          <div className="product-row">
            <div className="">
              <div className="deal_of_the_day h-100 bg--light">
                <div className="d-flex justify-content-center align-items-center py-4">
                  <h4 className="font-semibold text-[20px] font-Butler m-0 align-items-center  text-uppercase text-center px-2y">
                    Deal of the day
                  </h4>
                </div>
                <div className="recommended-product-card mt-0 min-height-auto">
                  <div className="d-flex justify-content-center align-items-center position-relative ">
                    <div className="h-[230px]">
                      <Image  className="aspect-1 h-[inherit]" alt="product" src={ProductImg}/>
                    </div>
                    <div className="product-stock">
                      <span className="badge rounded-pill bg-info-custome">-15%</span>
                    </div>
                  </div>

                  <div className="bg-transparent text-center mb-0">
                    <div className="px-0">
                      <p className="text-sm text-black font-medium  font-poppins leading-7 text-[15px] lg:text-[16px] line-clamp-1 mb-0 pt-1">
                        Stone Crystal Unique Design Necklace Woman Exquisite
                        Wild Short Clavicle Chain
                      </p>
                      <div className="mb-4 pt-1 d-flex flex-wrap justify-content-center align-items-center text-center gap-8">
                        <span className="text-[14px] font-semibold text-[#666]">
                          $5,000.00
                        </span>
                        <span className="text-accent text-[18px] font-bold text-[#000]">
                          $4,500.00
                        </span>
                      </div>
                      <div className="px-4">
                        <CustomLink
                          href="/product_details"
                          title="Shop Now"
                          bgColor="#29abe2"
                          hoverBgColor="#22a3da"
                          textColor="#ffffff"
                          hoverTextColor="#fff"
                          borderColor="#29abe2"
                          showArrow={true}
                        />
                      </div>
                    </div>
                  </div>
                </div>
              </div>
            </div>

            <div className="mt-3 mt-sm-0">
              <div className="flex justify-between items-start">
                <div className="common-heading mb-3 mb-sm-4">
                  <h3>New Arrivals </h3>
                </div>

                <div className="mb-3 mb-sm-0">
                  <CustomLink
                    href="/shop"
                    title="View All"
                    bgColor="#000"
                    hoverBgColor="#2eb7f1"
                    textColor="#ffffff"
                    hoverTextColor="#fff"
                    borderColor="#333"
                    showArrow={true}
                  />
                </div>
              </div>

              <div className="grid gap-[0.75rem] grid-cols-12 w-full">
                <div className="category-list col-span-12">
                  <Swiper
                    slidesPerView={4.3}
                    spaceBetween={25}
                    loop={true}
                    autoplay={{ delay: 2500 }}
                    navigation={false}
                    pagination={{ clickable: true }}
                    breakpoints={{
                      320: { slidesPerView: 1.1 },
                      480: { slidesPerView: 1.5 },
                      770: { slidesPerView: 2.1 },
                      1030: { slidesPerView: 3.5 },
                      1340: { slidesPerView: 4 },
                    }}
                  >
                    {/* {allProducts?.map((row,index)=>
         <SwiperSlide key={index}>
            <Product row={row}  />
          </SwiperSlide>)} */}
                    {[1, 2, 3, 4, 5, 6, 7].map((index) => (
                      <SwiperSlide key={index}>
                        <Product />
                      </SwiperSlide>
                    ))}
                  </Swiper>
                </div>
              </div>
            </div>
          </div>
        </div>
      </section>
    </>
  );
};

export default TrendingProduct;
