"use client";
import React, { useState, useEffect } from "react";
import "./header.css";
import Logo from "/public/elona-logo.svg";
import CartIcon from "/public/cart.svg";
import { MdCall } from "react-icons/md";
import Link from "next/link";
import { FiUser } from "react-icons/fi";
import { ImLocation2 } from "react-icons/im";
import { FaCaretDown, FaCaretUp } from "react-icons/fa";
import SideMenu from "./SideMenu";
import CustomLink from "@/app/shared/CustomLink";
import Image from "next/image";
import Search from "./Search";

function Header() {
  const [isAllCategoriesOpen, setAllCategoriesOpen] = useState(false);
  const [isProduct, setIsProduct] = useState(false);
  const [isLoginOpen, setIsLoginOpen] = useState(false);
  const [isSticky, setIsSticky] = useState(false);
  const [isWorkWithUs, setIsWorkWithUs] = useState(false);
  const [isProductOpen, setIsProductOpen] = useState(false);
  const [subMenuVisible, setSubMenuVisible] = useState({
    product1: false,
    product2: false,
    product3: false,
  });

  const toggleDropdown = (dropdownSetter) => {
    dropdownSetter((prev) => !prev);
  };

  const toggleSubMenu = (productKey) => {
    setSubMenuVisible((prevState) => ({
      ...prevState,
      [productKey]: !prevState[productKey],
    }));
  };

  const AllCategoriesMouseEnter = () => {
    setAllCategoriesOpen(true);
  };

  const AllCategoriesMouseLeave = () => {
    setAllCategoriesOpen(false);
  };

  const ProductMouseEnter = () => {
    setIsProduct(true);
  };

  const ProductMouseLeave = () => {
    setIsProduct(false);
  };

  const LoginMouseEnter = () => {
    setIsLoginOpen(true);
  };

  const LoginMouseLeave = () => {
    setIsLoginOpen(false);
  };

  const WorkWithUsMouseEnter = () => {
    setIsWorkWithUs(true);
  };

  const WorkWithUsMouseLeave = () => {
    setIsWorkWithUs(false);
  };

  // for scroll

  useEffect(() => {
    const handleScroll = () => {
      const scrollTop = window.pageYOffset;
      setIsSticky(scrollTop > 650);
    };

    window.addEventListener("scroll", handleScroll);

    return () => {
      window.removeEventListener("scroll", handleScroll);
    };
  });

  return (
    <>
      <header className={isSticky ? "sticky" : ""}>
        <div className="navigation-wrap">
          {/* top part */}

          <div className="w-100 d-none d-sm-flex justify-content-center  py-2 justify-content-lg-between align-items-center side-space sky-blue-bg">
            <div className="d-none d-lg-block">
              <p className="mb-0 header-text text-white">
                <span className="light-brwon">
                  {" "}
                  <b>Offer**</b>{" "}
                </span>
                  EXTRA 10% OFF ON MIN PURCHASE OF INR5,000.00
              </p>
            </div>

            <div className="top-menu text-right  d-none d-lg-block">
              <ul className="list-menu">
                <li className="nav-item m-0 ">
                  <Link
                    className="nav-link topmenu-padding text-white"
                    href="/about_us"
                  >
                    About Us
                  </Link>
                </li>

                <li className="nav-item m-0 ">
                  <Link
                    className="nav-link topmenu-padding text-white"
                    href="/contact_us"
                  >
                    Contact Us
                  </Link>
                </li>

                <li className="nav-item m-0 pe-0">
                  <Link
                    className="nav-link  topmenu-padding pe-0 text-white"
                    href="/track-order"
                  >
                    Track Order
                  </Link>
                </li>
              </ul>
            </div>

            <div className="top-menu text-right d-block d-lg-none pb-0 pb-sm-1">
              <ul className="list-menu">
                <li
                  className="d-none d-sm-block nav-item m-0 show"
                  onMouseEnter={WorkWithUsMouseEnter}
                  onMouseLeave={WorkWithUsMouseLeave}
                >
                  <Link
                    href="#"
                    className="ms-3 show text-capitalize rounded-md w-fit transition-all text-[14px] flex items-center gap-2 bg-[#000] border-1 border-[#000] hover:border-[#3333]  py-2 px-6   md:py-3  text-md text-[#fff] font-normal  leading-[24px] no-underline hover:text-[#fff] hover:bg-[#333] hover:border-[#6f6f6f]"
                    aria-haspopup="true"
                    aria-expanded={isWorkWithUs}
                  >
                    Work with us{" "}
                    {isWorkWithUs ? (
                      <FaCaretUp className="ms-2" />
                    ) : (
                      <FaCaretDown className="ms-2" />
                    )}
                  </Link>

                  {isWorkWithUs && (
                    <div
                      className="dropdown-menu dropdown-position"
                      onMouseEnter={WorkWithUsMouseEnter}
                      onMouseLeave={WorkWithUsMouseLeave}
                    >
                      <div
                        className="mega-box-signin"
                        style={{ width: "200px" }}
                      >
                        <div className="">
                          <ul className="inner-menu">
                            <li>
                              <Link className="dropdown-item" href="/dealer">
                                Become an Dealer
                              </Link>
                            </li>
                          </ul>
                        </div>
                      </div>
                    </div>
                  )}
                </li>
              </ul>
            </div>
          </div>

          <div className="hr-line m-0"></div>
          {/* middle  part */}

          <div className="side-space">
            <nav className="navbar navbar-expand-md flex-nowrap align-items-center pl-0 pr-0 d-flex justify-content-between">
              <div className="me-3 ">
                <Link className="navbar-brand flex" href="/">
                  <Image src={Logo} alt="Logo" />
                </Link>
              </div>
              <div className="w-60-tablet width-100 d-none d-md-block">
                <div className="navbar-collapse align-items-center">
                  <div className="ps-3 d-none-tablet">
                    <ul className="navbar-nav ms-2 align-items-center">
                      <li className="nav-item mr-0 m-0">
                        <Link
                          className="nav-link d-flex"
                          href="tel:(441)293-5476"
                        >
                          <ImLocation2 className="map-icon me-2" />

                          <span>
                            Deliver to DesignDot <br></br>
                            <b>New Delhi 110045‌</b>
                          </span>
                        </Link>
                      </li>
                    </ul>
                  </div>

                  {/* search */}
                  <div className="search w-60 w-tablet-100 mw-100 ps-0 ps-lg-5">
                    <Search></Search>
                  </div>
                  {/* end search */}
                  <div className="ps-3 d-none-tablet">
                    <ul className="navbar-nav ms-2 align-items-center">
                      <li className="nav-item mr-0 m-0">
                        <Link
                          className="nav-link d-flex"
                          href="tel:1800 212 1234"
                        >
                          <MdCall className="phone-img pr-2" />
                          <span>
                            Hotline <br />
                            <b>1800 212 1234 </b>
                          </span>
                        </Link>
                      </li>
                    </ul>
                  </div>
                </div>
              </div>

              <div className="w-40">
                {/* cart / login */}
                <div className="cart_login">
                  <ul className="d-flex align-items-center justify-content-end">
                    <li
                      className="nav-item show m-0 pe-2 pe-sm-3"
                      onMouseEnter={LoginMouseEnter}
                      onMouseLeave={LoginMouseLeave}
                    >
                      <Link
                        className="gray-btn text-capitalize p-0 pe-sm-0"
                        href="#"
                      >
                        <span className="px-3 d-none d-sm-block"> Login </span>
                        <FiUser className="login-user-icon" />
                      </Link>

                      {isLoginOpen && (
                        <div
                          className="dropdown-menu dropdown-position"
                          onMouseEnter={LoginMouseEnter}
                          onMouseLeave={LoginMouseLeave}
                        >
                          <div className="mega-box-signin">
                            <div className="login-btn mt-2 mb-2 text-center">
                              <div
                                className="text-center m-auto"
                                style={{ width: "130px" }}
                              >
                                <CustomLink
                                  href="/signin"
                                  title="Login"
                                  bgColor="#000"
                                  hoverBgColor="#333333"
                                  textColor="#ffffff"
                                  hoverTextColor="#ffffff"
                                  borderColor="#000"
                                  borderRadius="8px"
                                  showArrow={false}
                                />
                              </div>

                              <p className="fw-400 text-left fa-13 mb-0 pt-3">
                                New Customer ?
                                <Link
                                  href="/signin"
                                  className="text-capitalize ms-2 no-underline	 "
                                  style={{ color: "#C75E0A", fontSize: "14px" }}
                                >
                                  <b>Start Here</b>
                                </Link>
                              </p>
                            </div>

                            <div className="line"></div>
                            <div className="mega-box-1">
                              <div className="mega-menu-1 px-0">
                                <p className="menu-title mb-1">Your Account</p>
                                <ul
                                  className="inner-menu"
                                  style={{ width: "250px" }}
                                >
                                  <li>
                                    <Link className="dropdown-item" href="#">
                                      Account
                                    </Link>
                                  </li>
                                  <li>
                                    <Link
                                      className="dropdown-item"
                                      href="/wishlist"
                                    >
                                      Wishlist
                                    </Link>
                                  </li>
                                </ul>
                              </div>
                            </div>
                          </div>
                        </div>
                      )}
                    </li>
                    <li className="nav-item m-0 pe-0 pe-sm-1">
                      <Link href="/cart" className="text-decoration-none flex">
                        <Image
                          src={CartIcon}
                          className="cartimg"
                          alt="Cart Icon"
                        />
                        <span className="text-danger cart-no">
                          <b>2</b>
                        </span>
                      </Link>
                    </li>

                    <li className="nav-item m-0 d-none d-sm-block">
                      <Link href="#" className="cart-tot-text">
                        <b>Total</b>
                        <p className="cart-tot-value mb-0">$ 20</p>
                      </Link>
                    </li>
                  </ul>
                </div>
              </div>
            </nav>
          </div>

          <div className="hr-line m-0"></div>

          {/* bottom part */}

          <div className="side-space">
            <div className="bottom-header w-100 display-flex align-items-center pt-2 pb-2">
              <div className="w-custom">
                <ul className="catgory-list">
                  {/*start  sidemenu */}
                  <li className="nav-item">
                    <SideMenu />
                  </li>

                  {/*end  sidemenu */}
                </ul>
              </div>
              <div className="width-100 w-medium-80">
                {/*search  for mobile */}

                <div className="search w-60 w-tablet-100 mw-100 d-block d-md-none">
                  <Search></Search>
                </div>

                {/*search for mobile */}

                <div className="category-menu d-none d-md-block">
                  <ul className="list-bottom-menu">
                    <li
                      className="nav-item m-0 show"
                      onMouseEnter={() => setIsProductOpen(true)}
                      onMouseLeave={() => setIsProductOpen(false)}
                    >
                      <div className="position-relative">
                        <Link
                          className="nav-link topmenu-padding d-flex gap-1 align-items-center"
                          href="#"
                        >
                          All Products{" "}
                          {isProductOpen ? (
                            <FaCaretUp className="ms-2" />
                          ) : (
                            <FaCaretDown className="ms-2" />
                          )}
                        </Link>
                        {isProductOpen && (
                          <div
                            className="dropdown-menu"
                            style={{
                              width: "200px",
                              position: "absolute",
                              top: "100%",
                              left: "0",
                            }}
                          >
                            <ul
                              className="inner-menu"
                              style={{ width: "200px" }}
                            >
                              <li
                                className="nav-item show me-0"
                                onMouseEnter={() => toggleSubMenu("product1")}
                                onMouseLeave={() => toggleSubMenu("product1")}
                              >
                                <Link
                                  className="dropdown-item d-flex justify-between gap-1 align-items-center"
                                  href="#"
                                >
                                  Faucets{" "}
                                  {subMenuVisible.product1 ? (
                                    <FaCaretUp className="ms-2" />
                                  ) : (
                                    <FaCaretDown className="ms-2" />
                                  )}
                                </Link>
                                {subMenuVisible.product1 && (
                                  <div
                                    className="dropdown-menu"
                                    style={{
                                      position: "absolute",
                                      top: "0",
                                      left: "100%",
                                    }}
                                  >
                                    <ul
                                      className="inner-menu"
                                      style={{ width: "200px" }}
                                    >
                                      <li>
                                        <Link
                                          className="dropdown-item"
                                          href="/shop"
                                        >
                                          Divertors
                                        </Link>
                                      </li>
                                      <li>
                                        <Link
                                          className="dropdown-item"
                                          href="/shop"
                                        >
                                          Sensor faucets
                                        </Link>
                                      </li>
                                      <li>
                                        <Link
                                          className="dropdown-item"
                                          href="/shop"
                                        >
                                          Luxury faucets
                                        </Link>
                                      </li>
                                    </ul>
                                  </div>
                                )}
                              </li>

                              <li
                                className="nav-item show me-0"
                                onMouseEnter={() => toggleSubMenu("product2")}
                                onMouseLeave={() => toggleSubMenu("product2")}
                              >
                                <Link
                                  className="dropdown-item d-flex justify-between gap-1 align-items-center"
                                  href="#"
                                >
                                  Showers{" "}
                                  {subMenuVisible.product2 ? (
                                    <FaCaretUp className="ms-2" />
                                  ) : (
                                    <FaCaretDown className="ms-2" />
                                  )}
                                </Link>
                                {subMenuVisible.product2 && (
                                  <div
                                    className="dropdown-menu"
                                    style={{
                                      position: "absolute",
                                      top: "0",
                                      left: "100%",
                                    }}
                                  >
                                    <ul
                                      className="inner-menu"
                                      style={{ width: "200px" }}
                                    >
                                      <li>
                                        <Link
                                          className="dropdown-item"
                                          href="/shop"
                                        >
                                          Health faucets
                                        </Link>
                                      </li>
                                      <li>
                                        <Link
                                          className="dropdown-item"
                                          href="/shop"
                                        >
                                          Hand showers
                                        </Link>
                                      </li>
                                      <li>
                                        <Link
                                          className="dropdown-item"
                                          href="/shop"
                                        >
                                          Shower with arm
                                        </Link>
                                      </li>
                                    </ul>
                                  </div>
                                )}
                              </li>
                            </ul>
                          </div>
                        )}
                      </div>
                    </li>
                    <li
                      className="nav-item m-0 show"
                      onMouseEnter={ProductMouseEnter}
                      onMouseLeave={ProductMouseLeave}
                    >
                      <Link
                        className="nav-link topmenu-padding d-flex gap-1 align-items-center"
                        href="#"
                        aria-haspopup="true"
                        aria-expanded={isProduct}
                      >
                        Luxury Collection{" "}
                        {isProduct ? (
                          <FaCaretUp className="ms-2" />
                        ) : (
                          <FaCaretDown className="ms-2" />
                        )}
                      </Link>

                      {isProduct && (
                        <div
                          className="dropdown-menu "
                          onMouseEnter={ProductMouseEnter}
                          onMouseLeave={ProductMouseLeave}
                        >
                          <ul className="inner-menu" style={{ width: "200px" }}>
                            <li>
                              <Link className="dropdown-item" href="/shop">
                                Luxury Shower Drain Channel
                              </Link>
                            </li>
                            <li>
                              <Link className="dropdown-item" href="/shop">
                                Luxury Kitchen Sinks
                              </Link>
                            </li>
                          </ul>
                        </div>
                      )}
                    </li>

                    <li className="nav-item m-0 ">
                      <Link
                        className="nav-link topmenu-padding"
                        href="/whats-new"
                      >
                        {"What's New"}
                      </Link>
                    </li>

                    <li className="nav-item m-0 ">
                      <Link className="nav-link topmenu-padding" href="/deal">
                        Deals
                      </Link>
                    </li>

                    <li className="nav-item m-0 ">
                      <Link className="nav-link topmenu-padding" href="#">
                        Buy Again
                      </Link>
                    </li>
                  </ul>
                </div>
              </div>

              <div className="cart_login w-40 d-none d-lg-block">
                <ul className="ms-2 d-flex align-items-center justify-content-end">
                  <li
                    className="nav-item m-0 show"
                    onMouseEnter={WorkWithUsMouseEnter}
                    onMouseLeave={WorkWithUsMouseLeave}
                  >
                    <Link
                      href="#"
                      className="rounded-md w-fit transition-all text-[14px] flex items-center gap-2 bg-[#000] border-1 border-[#000] hover:border-[#3333]  py-2 px-6   md:py-3  text-md text-[#fff] font-normal  leading-[24px] no-underline hover:text-[#fff] hover:bg-[#333] hover:border-[#6f6f6f]"
                      aria-haspopup="true"
                      aria-expanded={isWorkWithUs}
                    >
                      Work with us{" "}
                      {isWorkWithUs ? (
                        <FaCaretUp className="ms-2" />
                      ) : (
                        <FaCaretDown className="ms-2" />
                      )}
                    </Link>

                    {isWorkWithUs && (
                      <div
                        className="dropdown-menu dropdown-position"
                        onMouseEnter={WorkWithUsMouseEnter}
                        onMouseLeave={WorkWithUsMouseLeave}
                      >
                        <div
                          className="mega-box-signin"
                          style={{ width: "200px" }}
                        >
                          <div className="">
                            <ul className="inner-menu">
                              <li>
                                <Link className="dropdown-item" href="/dealer">
                                  Become an Dealer
                                </Link>
                              </li>
                            </ul>
                          </div>
                        </div>
                      </div>
                    )}
                  </li>
                </ul>
              </div>
            </div>
          </div>
        </div>
      </header>
    </>
  );
}

export default Header;
