"use client";
import { useEffect, useState } from "react";
import "./mobilemenu.css";
import { BiChevronRight } from "react-icons/bi";
import Link from "next/link";
import { HiOutlineBars3CenterLeft } from "react-icons/hi2";
import authApi from "@/Api/authApi";

function MobileMenu() {
  const [menuLevels, setMenuLevels] = useState([]);
  const [cats, setcats] = useState([]);
  const [menuDataCat, setMenuDataCat] = useState([]);
  const [menuData, setMenuData] = useState([]);
  const getAllCats = async () => {
    try {
      const res = await authApi.get(`get-all-category`);
      const data = res?.data?.categories;
      const arr = data?.filter((ele) => ele?.parent_id == null);
      setcats(arr);
    } catch (error) {}
  };

  useEffect(() => {
    getAllCats();
  }, []);

  useEffect(() => {
    if (cats.length > 0) {
      const filter = cats?.map((ele) => ({
        id: ele?.id,
        label: ele?.name,
        link: `/product?page=1&cat_id=${ele.id}`,
        submenus: ele?.sub_category?.map((elem) => ({
          id: elem?.id,
          label: elem?.name,
          link: `/product?page=1&cat_id=${ele.id}&sub_cat_id=${elem.id}`,
          submenus: elem?.sub_sub_category?.map((el) => ({
            id: el.id,
            label: el.name,
            link: `/product?page=1&cat_id=${ele.id}&sub_cat_id=${elem.id}&sub_sub_cat=${el.id}`,
          })),
        })),
      }));

      setMenuDataCat(filter);
    }
  }, [cats]);

  const openNav = (level) => {
    const newLevels = [...menuLevels, level];
    setMenuLevels(newLevels);
  };

  const closeNav = () => {
    const newLevels = [...menuLevels];
    newLevels.pop();
    setMenuLevels(newLevels);
  };

  useEffect(() => {
    const arr = [
      {
        id: "a",
        label: "All products",
        link: "/product",
        submenus: [
          {
            id: "b",
            label: "ALL PRODUCT",
            link: "/product",
            submenus: menuDataCat,
          },
          { id: "c", label: "Whats New", link: "/product" },
          { id: "d", label: "About Us", link: "/about-us" },
          { id: "e", label: "Contact Us", link: "/contact-us" },
          { id: "f", label: "Download Catalog", link: "/download-catalog" },
          {
            id: "g",
            label: "BECOME A DEALER",
            link: "/become-a-dealer",
            submenus: [
              {
                id: "h",
                label: "DEALER",
                link: "/become-a-dealer/dealer",
              },
            ],
          },
          {
            id: "i",
            label: "Call Us: 1800 212 1234",
            link: "/tel:1800 212 1234",
          },
        ],
      },
    ];
    setMenuData(arr);
  }, [menuDataCat]);

  const renderMenu = (items, level) => {
    return (
      <div
        className={`sidepanel ${menuLevels.includes(level) ? "active" : ""}`}
      >
        <Link href="#" className="closebtn1" onClick={closeNav}>
          ×
        </Link>
        {items.map((item, index) => (
          <div key={index}>
            {item.submenus ? (
              <div className="submenu-toggle">
                <Link href={item?.link} onClick={() => setMenuLevels([])}>
                  {item.label}
                </Link>
                <BiChevronRight
                  className="text-[30px]"
                  onClick={() => openNav(item.id)}
                />
              </div>
            ) : (
              <Link href={item.link} onClick={() => setMenuLevels([])}>
                {item.label}
              </Link>
            )}
            {item.submenus && renderMenu(item.submenus, item.id)}
          </div>
        ))}
      </div>
    );
  };

  return (
    <div className="all-product-mobile">
      <button className="openbtn" onClick={() => openNav("a")}>
        <HiOutlineBars3CenterLeft
          style={{ fontSize: "30px", cursor: "pointer" }}
        />
      </button>
      {renderMenu(menuData, "a")}
    </div>
  );
}

export default MobileMenu;
