"use client";
import authApi from "@/Api/authApi";
import axios from "axios";
import Link from "next/link";
import { useEffect, useRef, useState } from "react";
import { BsSearch } from "react-icons/bs";

export default function SearchComponent() {
  const [search, setSearch] = useState("");
  const [results, setResults] = useState([]);
  const [showDrop, setShowDrop] = useState(false);
  const dropdownRef = useRef(null);

  let cancelToken;
  const getSearchResults = async () => {
    if (typeof cancelToken != typeof undefined) {
      cancelToken.cancel("Operation canceled due to new request.");
    }
    //Save the cancel token for the current request
    cancelToken = axios.CancelToken.source();

    try {
      if (search) {
        const res = await authApi.get(`search-product/${search}`, {
          cancelToken: cancelToken.token,
        });
        setResults(res?.data?.products);
        setShowDrop(true);
      } else {
        setResults([]);
        setShowDrop(false);
      }
    } catch (error) {}
  };
  useEffect(() => {
    getSearchResults();

    // Add event listener for clicks outside the dropdown
    document.addEventListener("mousedown", handleClickOutside);

    // Clean up the event listener on component unmount
    return () => {
      document.removeEventListener("mousedown", handleClickOutside);
      if (cancelToken) {
        cancelToken.cancel("Operation canceled due to component unmounting.");
      }
    };
  }, [search]);

  const handleInputFocus = () => {
    if (results.length > 0) {
      setShowDrop(true);
    }
  };

  const handleItemClick = (productName) => {
    setSearch(productName);
    setShowDrop(false);
  };
  const handleClickOutside = (event) => {
    if (dropdownRef.current && !dropdownRef.current.contains(event.target)) {
      setShowDrop(false);
    }
  };

  return (
    <>
      <form className="position-relative">
        <div className="flex items-center border rounded-full pl-3">
          <input
            className="w-full outline-none bg-transparent"
            type="text"
            placeholder="SEARCH PRODUCT"
            onChange={(e) => setSearch(e.target.value)}
            value={search}
            onFocus={handleInputFocus}
          />
          <button className="w-[40px] h-[35px] rounded-full bg-[#29549F] text-center flex justify-center items-center ">
            <BsSearch className="text-white font-bold text-lg" />
          </button>
        </div>
        {showDrop && (
          <div
            ref={dropdownRef}
            className="position-absolute bg-[#F4F4F4] w-100 p-2"
            style={{ zIndex: "11", top: "40px", borderRadius: "8px" }}
          >
            {results?.length > 0 &&
              results?.map((row, index) => (
                <Link
                  href={`/product_details/${row?.id}`}
                  key={index}
                  onClick={() => {
                    setShowDrop(false);
                  }}
                  className={`text-black cursor-pointer p-2 text-left  hover:bg-gray-300 text-sm no-underline block text-[12px] md:text-[14px] ${
                    index != results.length - 1 && "border-b"
                  } w-100 p-2 uppercase font-bold transition-all bg-[#F4F4F4] hover:no-underline`}
                >
                  {row?.product_name}
                </Link>
              ))}
            {search && results?.length == 0 && (
              <Link
                href="#"
                className={`text-black cursor-pointer p  hover:bg-gray-300 text-sm no-underline block text-[12px] md:text-[14px]
                 w-100 p-2 uppercase font-bold transition-all bg-[#F4F4F4] hover:no-underline`}
              >
                No result found!
              </Link>
            )}
          </div>
        )}
      </form>
    </>
  );
}
