"use client";
import React, { useState } from "react";
import "./produc-content.css";
import { Swiper, SwiperSlide } from "swiper/react";
import "swiper/swiper.min.css";
import "swiper/css";
import "swiper/css/pagination";
import "swiper/css/navigation";
import Range from "./Range";
import { FaRegStar } from "react-icons/fa6";

import { AiFillStar } from "react-icons/ai";
import { FaRegStarHalfStroke } from "react-icons/fa6";
import ProductQty from "./ProductQty";
import ShowMoreText from "react-show-more-text";
import RatingModal from "../review/RatingModal";
import QuickCart from "./QuickCart";

const ProductContent = ({ productDetail, getProductDetails }) => {
  const [qty, setQty] = useState(1);
  const [selectedModel, setSelectedModel] = useState({});

  const [expanded, setExpanded] = useState(false);

  const toggleExpansion = () => {
    setExpanded(!expanded);
  };

  const getAvgOfReviews = () => {
    const reviews = productDetail?.review;
    if (reviews?.length === 0) {
      return 0; // Return 0 if the array is empty to avoid division by zero
    }
    const totalStars = reviews?.reduce((sum, review) => sum + review.star, 0);
    const average = totalStars / reviews?.length;

    const roundedAverage = Math.round(average * 2) / 2;
      return roundedAverage;
   
  };

  
function getReviewIcon(averageReview) {
  if (averageReview < 0 || averageReview > 5) {
    averageReview = 0; // Set average review to 0 if it's out of range
  }

  const fullStars = Math.floor(averageReview);
  const hasHalfStar = averageReview % 1 !== 0;
  const emptyStars = 5 - fullStars - (hasHalfStar ? 1 : 0);

  const iconArray = [];
  for (let i = 0; i < fullStars; i++) {
    iconArray.push(<AiFillStar key={i} className="text-orange-300" />);
  }

  if (hasHalfStar) {
    iconArray.push(
      <FaRegStarHalfStroke key="half" className="text-orange-300" />
    );
  }

  for (let i = 0; i < emptyStars; i++) {
    iconArray.push(<FaRegStar key={i} className="text-orange-300" />);
  }

  return <>{iconArray}</>;
}

  const handleSelectModel = (range) => {
    setSelectedModel(range);
  };
  return (
    <>
      <div className="product-content mt-4 md:mt-0">
        <h3>{productDetail?.product_name}</h3>
        <p>
          <span className="font-medium text-[#333] ">Categories :</span>{" "}
          {productDetail?.category_name ?? "-"}
        </p>
        <div className="product-rating">
          <p className="flex items-center">
            {getReviewIcon(getAvgOfReviews())}
            {/* <AiFillStar className="text-orange-300 " />
            <FaRegStarHalfStroke className="text-orange-300 " />
            <AiFillStar className="text-orange-300 " />
            <AiFillStar className="text-orange-300 " />  */}
            | {productDetail?.review?.length} reviews
          </p>
        </div>

        {/* <div className="prices">
          <span className="compare-price line-through text-sm md:text-lg text-[#666]">
            Rs. 9,834
          </span>
          <span className="price on-sale ml-2 text-sm sm:text-lg text-[#333]">
            Rs. 6,392
          </span>
          <span className="discount_price text-sm sm:text-lg text-green-700 font-semibold ml-2 ">
            (35% off)
          </span>
        </div> */}

        <div className="mt-2">
          <ProductQty qty={qty} setQty={setQty} />
        </div>

        <div className="mt-3">
          <Swiper
            slidesPerView={5}
            spaceBetween={10}
            loop={true}
            autoplay={{ delay: 2500 }}
            navigation={false}
            pagination={{ clickable: true }}
            breakpoints={{
              0: { slidesPerView: 2, margin: 0 },
              400: { slidesPerView: 3 },
              800: { slidesPerView: 3 },
              1200: { slidesPerView: 4 },
              1399: { slidesPerView: 5 },
            }}
          >
            {productDetail?.product_details?.map((range) => (
              <SwiperSlide key={range.id}>
                <div
                  className={`range border text-center transition-colors cursor-pointer border-[#29549F] p-2 rounded bg-${
                    range?.id == selectedModel?.id ? "[#29549F]" : "blue-50"
                  } hover:bg-[#29549F]`}
                  onClick={() => handleSelectModel(range)}
                >
                  <h4
                    className={`text-lg text-${
                      range?.id == selectedModel?.id ? "white" : "[#333]"
                    } font-medium`}
                  >
                    ₹{range?.price}{" "}
                  </h4>
                  <p
                    className={`text-lg text-${
                      range?.id == selectedModel?.id ? "white" : "[#333]"
                    }  font-normal`}
                  >
                    <b>Item </b> - {range?.product_modal}
                  </p>
                  <p
                    className={`text-lg text-${
                      range?.id == selectedModel?.id ? "white" : "[#333]"
                    }  font-normal`}
                  >
                    <b>Size </b> - {range?.product_size}
                  </p>
                </div>
              </SwiperSlide>
            ))}
            {/* {ranges.map((range) => (
              <SwiperSlide key={range.id}>
                <Range label={range.label} item={range.item} />
              </SwiperSlide>
            ))} */}
          </Swiper>
        </div>

        <div className="my-3 w-[225px]">
          <QuickCart
            qty={qty}
            setQty={setQty}
            selectedModel={selectedModel}
            productDetail={productDetail}
          />
        </div>

        <div className="product-description">
          <h3>Description</h3>
          <ShowMoreText
            lines={4}
            more="Read More"
            less="Read Less"
            onClick={toggleExpansion}
            expanded={expanded}
          >
            <p className="">{productDetail?.product_desc ?? "Not given !"}</p>
          </ShowMoreText>
        </div>

        <div>
          <RatingModal
            productId={productDetail?.id}
            getProductDetails={getProductDetails}
          />
        </div>
      </div>
    </>
  );
};

export default ProductContent;
