"use client";
import React, { useEffect, useState } from "react";
import styles from "./modal.module.css";
import { AiOutlineClose } from "react-icons/ai";
import axios from "axios";
import { APIBASE } from "@/Api/apiConfig";
const initialState = {
  product_id: "",
  name: "",
  email: "",
  headline: "",
  review: "",
  star: "",
};
const RatingModal = ({ productId,getProductDetails }) => {
  const [state, setState] = useState(initialState);
  const [isPopupOpen, setIsPopupOpen] = useState(false);
  const [saving, setSaving] = useState(false);

  const openPopup = () => {
    setIsPopupOpen(true);
  };

  const closePopup = () => {
    setIsPopupOpen(false);
  };

  const handleStarChange = (e) => {
    setState({ ...state, star: e.target.value });
  };

  useEffect(() => {
    setState({ ...state, product_id:productId });
  }, [productId]);

  const handlePostReview = async (e) => {
    e.preventDefault();
    setSaving(true);
    try {
      await axios.post(`${APIBASE}create-review`, state);
      console.log("1");
      getProductDetails()
      setSaving(false);
      setIsPopupOpen(false);
    } catch (error) {
      setIsPopupOpen(false);
      setSaving(false);
    }
  };

  return (
    <>
      <div className="mt-3">
        <button
          onClick={openPopup}
          className="py-[10px] px-4  text-lg w-[230px] text-white rounded  font-semibold transition-colors bg-[#054878] hover:bg-[#29549F] "
        >
          Write a review
        </button>
      </div>

      {isPopupOpen && (
        <div className={styles["popup-overlay"]}>
          <div className={`w-[100%] m-2 sm:w-[500px] ${styles.popup}`}>
            <div className={styles.modaldialog}>
              <div className="flex justify-between items-center    border-b">
                <div>
                  <h3 className="text-lg text-[#333] font-poppins font-medium">
                    Post Your Product Review
                  </h3>
                </div>
                <div>
                  <button
                    className={styles["close-button"]}
                    onClick={closePopup}
                  >
                    <AiOutlineClose className="text-lg font-semibold" />
                  </button>
                </div>
              </div>

              <form onSubmit={(e) => handlePostReview(e)}>
                <div className="mt-3">
                  <div className="p-0 ">
                    <div className={styles.ratebox}>
                      <h4>Overall rating</h4>
                      <div className={`mt-3 mb-3 ${styles.starrating}`}>
                        <input
                          type="radio"
                          id="5-stars"
                          name="rating"
                          value="5"
                          onChange={handleStarChange}
                        />
                        <label for="5-stars" className={styles.star}>
                          ★
                        </label>
                        <input
                          type="radio"
                          id="4-stars"
                          name="rating"
                          value="4"
                          onChange={handleStarChange}
                        />
                        <label for="4-stars" className={styles.star}>
                          ★
                        </label>
                        <input
                          type="radio"
                          id="3-stars"
                          name="rating"
                          value="3"
                          onChange={handleStarChange}
                        />
                        <label for="3-stars" className={styles.star}>
                          ★
                        </label>
                        <input
                          type="radio"
                          id="2-stars"
                          name="rating"
                          value="2"
                          onChange={handleStarChange}
                        />
                        <label for="2-stars" className={styles.star}>
                          ★
                        </label>
                        <input
                          type="radio"
                          id="1-star"
                          name="rating"
                          value="1"
                          onChange={handleStarChange}
                        />
                        <label for="1-star" className={styles.star}>
                          ★
                        </label>
                      </div>
                    </div>
                  </div>

                  <div className="p-0">
                    <div className="form-group">
                      <input
                        type="text"
                        name="name"
                        value={state?.name}
                        onChange={(e) =>
                          setState({ ...state, name: e.target.value })
                        }
                        className="p-[10px] border rounded w-100 focus:outline-none"
                        placeholder="Name"
                        required=""
                      />
                    </div>
                  </div>

                  <div className="p-0">
                    <div className="form-group">
                      <input
                        type="text"
                        name="email"
                        value={state?.email}
                        onChange={(e) =>
                          setState({ ...state, email: e.target.value })
                        }
                        className="p-[10px] border rounded w-100 focus:outline-none"
                        placeholder="Email"
                        required=""
                      />
                    </div>
                  </div>

                  <div className="p-0">
                    <div className="form-group">
                      <input
                        type="text"
                        name="headline"
                        value={state?.headline}
                        onChange={(e) =>
                          setState({ ...state, headline: e.target.value })
                        }
                        className="p-[10px] border rounded w-100 focus:outline-none"
                        placeholder="Add a headline"
                        required=""
                      />
                    </div>
                  </div>

                  <div className="p-0">
                    <div className="form-group">
                      <textarea
                        className="p-[10px] border rounded w-100 focus:outline-none"
                        value={state?.review}
                        onChange={(e) =>
                          setState({ ...state, review: e.target.value })
                        }
                        name="review"
                        placeholder="Write your review"
                      ></textarea>
                    </div>
                  </div>

                  <div className="p-0  mt-3 text-center">
                    <input
                      type="submit"
                      name="submit"
                      disabled={saving}
                      value={saving ? "Submitting" : "Submit"}
                      className="py-[12px] px-4 text-white rounded transition-colors bg-[#29549F] hover:bg-[#054878]"
                    />
                  </div>
                </div>
              </form>
            </div>
          </div>
        </div>
      )}
    </>
  );
};

export default RatingModal;
