"use client";
import React, { useEffect, useState } from "react";
import styles from "../review/modal.module.css";
import { AiOutlineClose } from "react-icons/ai";
import Link from "next/link";
import prodImg from "/public/product/prod-1.jpg";
import ProductQty from "./ProductQty";
import ScrollToTop from "../../../shared/ScrollToTop";
import Image from "next/image";
import { IMAGEURL } from "@/Api/apiConfig";
import { ToastContainer } from "react-toastify";
import "react-toastify/dist/ReactToastify.css";
import { toast } from "react-toastify";
import { useDispatch, useSelector } from "react-redux";
import { addProduct, deleteProduct } from "@/Redux/cartSlice";
import { BsArrowRight } from "react-icons/bs";

const QuickCart = ({ qty, setQty, selectedModel, productDetail }) => {
  const [isPopupOpen, setIsPopupOpen] = useState(false);
  const cartItems = useSelector((state) => state?.userCart?.products);

  const dispatch = useDispatch();
  const openPopup = () => {
    if (selectedModel?.id) {
      const payload = {
        image: productDetail?.thumbnail,
        images: productDetail?.images,
        id: productDetail?.id,
        category: productDetail?.category_name,
        model: selectedModel,
        qty: qty,
        sub_category: productDetail?.sub_category_name,
        product_name: productDetail?.product_name,
      };
      dispatch(addProduct(payload));
      setIsPopupOpen(true);
    } else {
      toast.warn("Select model first!");
    }
  };
  //   useEffect(() => {
  // const filter=cartItems?.filter((ele)=>ele?.id==productDetail?.id)
  // if(filter?.length>0 && filter[0].model?.id){
  //   const payload = {
  //     image: productDetail?.thumbnail,
  //     images: productDetail?.images,
  //     id: productDetail?.id,
  //     category: productDetail?.category_name,
  //     model: selectedModel,
  //     qty: qty,
  //     sub_category:productDetail?.sub_category_name,
  //     product_name:productDetail?.product_name
  //   };
  //   dispatch(addProduct(payload));
  // }

  // }, [qty]);

  const closePopup = () => {
    setIsPopupOpen(false);
  };

  const handleLinkClick = () => {
    ScrollToTop();
  };

  const getImg = (row) => {
    if (row?.image) {
      return `${IMAGEURL}${row?.image}`;
    } else if (row?.images?.length > 0) {
      const filter = row?.images?.filter((ele) => ele?.url);
      if (filter?.length > 0) {
        return `${IMAGEURL}${filter[0].url}`;
      }
    }
  };
  const handleRemoveItem = (row) => {
    dispatch(deleteProduct(row));
  };

  const getTotal = () => {
    const sum = cartItems?.reduce((a, c) => {
      return c.qty * c.model.price + a;
    }, 0);

    return sum;
  };

  console.log(cartItems);
  return (
    <>
      <ToastContainer />
      <div>
        <Link
          href="#"
          title="Add to Cart"
          onClick={openPopup}
          className="rounded-md w-fit transition-all duration-300 text-[16px] flex items-center gap-2 bg-[#000]    px-5  lg:px-10 py-[10px]  text-md text-[#fff] font-medium  leading-[24px] no-underline hover:text-[#fff] hover:bg-[#29abe2]"
        >
          Add to Cart <BsArrowRight />
        </Link>
      </div>

      {isPopupOpen && (
        <div className={styles["popup-overlay"]}>
          <div className={`w-[100%] m-2 md:w-[75%]  ${styles.popup}`}>
            <div className={styles.modaldialog}>
              <div className="flex justify-between items-center border-b">
                <div className="w-[90%]">
                  <p className="text-md text-center text-[#333] mb-2 font-poppins font-medium">
                    The following items has been added to your cart
                  </p>
                </div>
                <div>
                  <button
                    className={styles["close-button"]}
                    onClick={closePopup}
                  >
                    <AiOutlineClose className="text-lg font-semibold" />
                  </button>
                </div>
              </div>

              <div className={styles.cart}>
                <div className="grid  grid-cols-1 lg:grid-cols-3 gap-3 mt-3 lg:gap-6 2xl:gap-10">
                  <div className="col-span-12 lg:col-span-2">
                    <div className="table-responsive !w-100">
                      <table className="table border w-100 mb-0">
                        <thead>
                          <tr className="bg-gray-100 ">
                            <th>Products</th>
                            <th>Qty</th>
                            <th>Price</th>
                            <th></th>
                          </tr>
                        </thead>
                        <tbody>
                          {cartItems?.map((row, index) => (
                            <tr key={index}>
                              <td>
                                <div className="flex w-[300px]">
                                  <div>
                                    <Image
                                      src={getImg(row)}
                                      width={80}
                                      height={120}
                                      alt="product"
                                      className="w-[80px] h-[80px] mr-5"
                                    />
                                  </div>
                                  <div>
                                    <p className="text-sm text-[#333] font-normal">
                                      {row?.product_name ?? "unknown"}
                                    </p>
                                  </div>
                                </div>
                              </td>
                              <td>
                                {" "}
                                <SingleRow
                                  selectedModel={selectedModel}
                                  quantity={row?.qty}
                                  row={row}
                                  cartItems={cartItems}
                                  productDetail={productDetail}
                                />
                                {/* {row?.qty} */}
                                {/* <ProductQty qty={qty} setQty={setQty} /> */}
                              </td>
                              <th>{row?.model?.price}</th>
                              <th>
                                {" "}
                                <button onClick={() => handleRemoveItem(row)}>
                                  {" "}
                                  <AiOutlineClose className="text-lg font-semibold" />
                                </button>
                              </th>
                            </tr>
                          ))}

                          {/* <tr>
                            <td>
                              <div className="flex w-[300px]">
                                <div>
                                  <Image
                                    src={getImg()}
                                    width={80}
                                    height={120}
                                    alt="product"
                                    className="w-[100px] h-[80px] mr-5"
                                  />
                                </div>
                                <div>
                                  <p className="text-sm text-[#333] font-normal">
                                    {productDetail?.product_name ?? "unknown"}
                                  </p>
                                </div>
                              </div>
                            </td>
                            <td>
                              <ProductQty qty={qty} setQty={setQty} />
                            </td>
                            <td>
                              <b>Rs. {selectedModel?.price}</b>
                            </td>
                            <td>
                              <button onClick={()=>handleRemoveItem()} >
                                {" "}
                                <AiOutlineClose className="text-lg font-semibold" />
                              </button>
                            </td>
                          </tr> */}
                        </tbody>
                      </table>
                    </div>
                  </div>

                  <div className="col-span-12 lg:col-span-1">
                    <table className="table border w-100 mb-0">
                      <thead>
                        <tr className="bg-gray-100 text-center">
                          <th>Quick cart</th>
                        </tr>
                      </thead>
                      <tbody>
                        <tr>
                          <td>
                            <p className="text-sm text-[#333] font-normal  text-center">
                              {cartItems?.length} items in your shopping cart
                            </p>
                          </td>
                        </tr>
                      </tbody>
                    </table>
                    <hr />
                    <div className={`mt-3 {styles.total}`}>
                      <div className="flex justify-between items-start">
                        <p className="!text-[#333] text-lg !font-medium ">
                          Total:
                        </p>
                        <p className="!text-[#333] text-lg !font-semibold ">
                          Rs. {getTotal()}
                        </p>
                      </div>
                    </div>

                    <div className="mt-4 block xl:flex xl:justify-between">
                      <Link
                        href="/product"
                        onClick={handleLinkClick}
                        className="text-[12px] md:text-[14px] !border  !border-black  transition-color py-[12px] w-100 !font-semibold  block px-2  text-[#333] text-center uppercase hover:bg-black hover:text-white hover:no-underline mr-[0px] xl:mr-1"
                      >
                        Continue Shopping
                      </Link>
                      <Link
                        href="/cart"
                        onClick={handleLinkClick}
                        className="text-[12px] md:text-[14px] !border  transition-color !font-semibold border-black py-[12px] w-100 block px-2 text-[#333] text-center uppercase hover:bg-black hover:text-white hover:no-underline ml-[0px] mt-[0.5rem] xl:!mt-0 xl:ml-1"
                      >
                        View Cart
                      </Link>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </div>
      )}
    </>
  );
};

const SingleRow = ({
  quantity,
  row,
  cartItems,
  productDetail,
  selectedModel,
}) => {
  const [qty, setQty] = useState(quantity);
  const dispatch = useDispatch();
  useEffect(() => {
    const filter = cartItems?.filter((ele) => ele?.id == productDetail?.id);
    if (filter?.length > 0 && filter[0].model?.id) {
      const payload = {
        image: productDetail?.thumbnail,
        images: productDetail?.images,
        id: productDetail?.id,
        category: productDetail?.category_name,
        model: selectedModel,
        qty: qty,
        sub_category: productDetail?.sub_category_name,
        product_name: productDetail?.product_name,
      };
      dispatch(addProduct(payload));
    }
  }, [qty]);

  return <ProductQty qty={qty} setQty={setQty} />;
};

export default QuickCart;
