"use client";
import React from "react";
import PropTypes from "prop-types";
import Link from "next/link";
import { BsArrowRight } from "react-icons/bs";

const CustomLink = ({
  href,
  title,
  bgColor,
  hoverBgColor,
  textColor,
  hoverTextColor,
  borderColor,
  borderRadius,
  showArrow,
}) => {
  return (
    <Link
      href={href}
      className={`rounded-full d-flex relative z-[99] justify-center w-[100%] transition-all duration-300 text-[12px] md:text-[14px] flex items-center gap-2 py-[.25rem] md:py-2 px-[1rem] md:px-6 lg:px-8  text-md font-medium leading-[24px] no-underline`}
      style={{
        backgroundColor: bgColor,
        color: textColor,
        border: `1px solid ${borderColor}`,
        borderRadius: borderRadius,
      }}
      onMouseEnter={(e) => {
        e.target.style.backgroundColor = hoverBgColor;
        e.target.style.color = hoverTextColor;
        e.target.style.borderColor = hoverBgColor;
      }}
      onMouseLeave={(e) => {
        e.target.style.backgroundColor = bgColor;
        e.target.style.color = textColor;
        e.target.style.borderColor = borderColor;
      }}
    >
      {title} {showArrow && <BsArrowRight />}
    </Link>
  );
};

CustomLink.propTypes = {
  href: PropTypes.oneOfType([PropTypes.string, PropTypes.object]).isRequired,
  title: PropTypes.string.isRequired,
  bgColor: PropTypes.string,
  hoverBgColor: PropTypes.string,
  textColor: PropTypes.string,
  hoverTextColor: PropTypes.string,
  borderColor: PropTypes.string,
  borderRadius: PropTypes.string,
  showArrow: PropTypes.bool,
};

CustomLink.defaultProps = {
  bgColor: "#000",
  hoverBgColor: "#333",
  textColor: "#fff",
  hoverTextColor: "#fff",
  borderColor: "#000",
  borderRadius: "50px",
  showArrow: true,
};

export default CustomLink;
