import React, { useState } from "react";
import Checkbox from "../../app/shared/Checkbox";
import { FaCaretUp, FaCaretDown } from "react-icons/fa";
import "./product_sidebar.css";
import PriceRangeFilter from "./component/PriceRangeFilter";
import { FaBars } from "react-icons/fa6";


const Sidebar = () => {
  // State for each accordion section
  const [isProductTypeOpen, setIsProductTypeOpen] = useState(true);
  const [isColorOpen, setIsColorOpen] = useState(true);
  const [isRangePriceOpen, setIsRangePriceOpen] = useState(true);
  const [isCategoryOpen, setIsCategoryOpen] = useState(true);
  const [isSidebarMobile, setIsSidebarMobile] = useState(true);

  // Toggle functions for each section
  const toggleProductTypeAccordion = () => {
    setIsProductTypeOpen(!isProductTypeOpen);
  };

  const toggleColorAccordion = () => {
    setIsColorOpen(!isColorOpen);
  };

  const togglePriceRangeAccordion = () => {
    setIsRangePriceOpen(!isRangePriceOpen);
  };

  const toggleCategoryAccordion = () => {
    setIsCategoryOpen(!isCategoryOpen);
  };

  const handleMobileSidebar = () => {
    if (window.innerWidth <= 767) {
      setIsSidebarMobile(!isSidebarMobile);
    }
  };

  React.useEffect(() => {
    const handleResize = () => {
      if (window.innerWidth > 767 ) {
        setIsSidebarMobile(true);
      } else if (window.innerWidth <= 767 && isSidebarMobile) {
        setIsSidebarMobile(false);
      }
    };

    window.addEventListener('resize', handleResize);

    return () => window.removeEventListener('resize', handleResize);
  }, [isSidebarMobile]);


  return (
<>
    
    <button className="filter-none mb-3 rounded-full w-fit transition-all text-[16px] flex items-center gap-2 bg-[#000] border-1 border-[#000] hover:border-[#3333]  py-2 px-4  text-md text-[#fff] font-medium  leading-[24px] no-underline hover:text-[#fff] hover:bg-[#333] hover:border-[#6f6f6f]" onClick={handleMobileSidebar}>
    <FaBars />  Filter 
    </button>
   
    {isSidebarMobile && (

<div className="sidebar">
      {/*start price range */}
      <div className="sidebar-section bg-[#c9c9c91c] p-3 rounded-lg">
        <h3
          className="flex  justify-between text-sm bg-[#444444] rounded text-[#fff] text-transform p-2 font-normal font-poppins leading-7 text-[15px] lg:text-[16px] items-center cursor-pointer"
          onClick={togglePriceRangeAccordion}
        >
          Price Range
          {isRangePriceOpen ? (
            <FaCaretUp className="ml-2" />
          ) : (
            <FaCaretDown className="ml-2" />
          )}
        </h3>
        {isRangePriceOpen && (
            <div className="mt-3">
            <PriceRangeFilter />
          </div>
        )}
      </div>

      {/*end start price range */}

      {/*start Categories  range */}
      <div className="sidebar-section bg-[#c9c9c91c] p-3 rounded-lg">
        <h3
          className="flex  justify-between text-sm bg-[#444444] rounded text-[#fff] text-transform p-2 font-normal font-poppins leading-7 text-[15px] lg:text-[16px] items-center cursor-pointer"
          onClick={toggleCategoryAccordion}
        >
          Categories
          {isCategoryOpen ? (
            <FaCaretUp className="ml-2" />
          ) : (
            <FaCaretDown className="ml-2" />
          )}
        </h3>
        {isCategoryOpen && (
          <div className="mt-3">
            <div className="flex justify-between items-center">
              <Checkbox label="Faucet" />
              <span className="text-[12px] text-[#666] font-normal font-poppins">
                (40)
              </span>
            </div>
            <div className="flex justify-between items-center">
              <Checkbox label="Shower" />
              <span className="text-[12px] text-[#666] font-normal font-poppins">
                (143)
              </span>
            </div>
            <div className="flex justify-between items-center">
              <Checkbox label="Accessories" />
              <span className="text-[12px] text-[#666] font-normal font-poppins">
                (7)
              </span>
            </div>
          </div>
        )}
      </div>

      {/*End Categories  range */}

      {/*start Product type range */}
      <div className="sidebar-section bg-[#c9c9c91c] p-3 rounded-lg">
        <h3
          className="flex  justify-between text-sm bg-[#444444] rounded text-[#fff] text-transform p-2 font-normal font-poppins leading-7 text-[15px] lg:text-[16px] items-center cursor-pointer"
          onClick={toggleProductTypeAccordion}
        >
          Product type
          {isProductTypeOpen ? (
            <FaCaretUp className="ml-2" />
          ) : (
            <FaCaretDown className="ml-2" />
          )}
        </h3>
        {isProductTypeOpen && (
           <div className="mt-3">
            <div className="flex justify-between items-center">
              <Checkbox label="Allied Items" />
              <span className="text-[12px] text-[#666] font-normal font-poppins">
                (133)
              </span>
            </div>
            <div className="flex justify-between items-center">
              <Checkbox label="Bath Accessories" />
              <span className="text-[12px] text-[#666] font-normal font-poppins">
                (13)
              </span>
            </div>
            <div className="flex justify-between items-center">
              <Checkbox label="Kitchen Sinks" />
              <span className="text-[12px] text-[#666] font-normal font-poppins">
                (7)
              </span>
            </div>
            <div className="flex justify-between items-center">
              <Checkbox label="Shower Drain Channel" />
              <span className="text-[12px] text-[#666] font-normal font-poppins">
                (83)
              </span>
            </div>
            <div className="flex justify-between items-center">
              <Checkbox label="Wash basin" />
              <span className="text-[12px] text-[#666] font-normal font-poppins">
                (12)
              </span>
            </div>
            <div className="flex justify-between items-center">
              <Checkbox label="Western Toilets (EWCs)" />
              <span className="text-[12px] text-[#666] font-normal font-poppins">
                (1)
              </span>
            </div>
            <div className="flex justify-between items-center">
              <Checkbox label="Drain Covers & Strainers" />
              <span className="text-[12px] text-[#666] font-normal font-poppins">
                (45)
              </span>
            </div>
          </div>
        )}
      </div>

      {/*End Product type range */}

      {/*start Color  range */}

      <div className="sidebar-section bg-[#c9c9c91c] p-3 rounded-lg">
        <h3
          className="flex  justify-between text-sm bg-[#444444] rounded text-[#fff] text-transform p-2 font-normal font-poppins leading-7 text-[15px] lg:text-[16px] items-center cursor-pointer"
          onClick={toggleColorAccordion}
        >
          Color
          {isColorOpen ? (
            <FaCaretUp className="ml-2" />
          ) : (
            <FaCaretDown className="ml-2" />
          )}
        </h3>
        {isColorOpen && (
            <div className="mt-3">
            <div className="flex justify-between items-center">
              <Checkbox label="Black" />
            </div>
            <div className="flex justify-between items-center">
              <Checkbox label="Silver" />
            </div>
            <div className="flex justify-between items-center">
              <Checkbox label="Gold" />
            </div>
            <div className="flex justify-between items-center">
              <Checkbox label="Crystal White" />
            </div>
          </div>
        )}
      </div>

      {/*end Color  range */}
    </div>


    )}
    
    </>
  );
};

export default Sidebar;
