import React, { useState } from "react";
import styles from "./range_filter.module.css";

export default function PriceRangeSlider() {
  const [minValue, setMinValue] = useState(250);
  const [maxValue, setMaxValue] = useState(800);
  const min = 0;
  const max = 1000;
  const step = 50;

  const handleMinChange = (event) => {
    const value = Math.min(Number(event.target.value), maxValue - step);
    setMinValue(value);
  };

  const handleMaxChange = (event) => {
    const value = Math.max(Number(event.target.value), minValue + step);
    setMaxValue(value);
  };

  return (
    <div className={styles.sliderContainer}>
      <div className={styles.slider}>
        <input
          type="range"
          min={min}
          max={max}
          step={step}
          value={minValue}
          onChange={handleMinChange}
          className={styles.range}
        />
        <input
          type="range"
          min={min}
          max={max}
          step={step}
          value={maxValue}
          onChange={handleMaxChange}
          className={styles.range}
        />
        <div
          className={styles.filledRange}
          style={{
            left: `${((minValue - min) / (max - min)) * 100}%`,
            right: `${100 - ((maxValue - min) / (max - min)) * 100}%`
          }}
        />
      </div>
      <div className={styles.values}>
        <span className="text-dark">{minValue.toLocaleString("en-US", { style: "currency", currency: "USD" })}</span>
        <span className="text-dark">{maxValue.toLocaleString("en-US", { style: "currency", currency: "USD" })}</span>
      </div>
    </div>
  );
}
